@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -15,7 +18,7 @@ import cdktf._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@cdk8s/cdktf-resolver", "0.0.15", __name__[0:-6], "cdktf-resolver@0.0.15.jsii.tgz"
+    "@cdk8s/cdktf-resolver", "0.0.89", __name__[0:-6], "cdktf-resolver@0.0.89.jsii.tgz"
 )
 
 __all__ = [
